if IsAddOnLoaded("Titan") and not IsAddOnLoaded("FuBar") then
	-- Do not load if Titanbar is loaded
	return
end

local beql = LibStub("AceAddon-3.0"):GetAddon("beql")
local L = LibStub("AceLocale-3.0"):GetLocale("beql")
beqlfu = Rock:NewAddon("beqlFu", "LibFuBarPlugin-3.0", "LibRockDB-1.0")
local GameTooltip = GameTooltip
local AceConfigReg	=	LibStub("AceConfigRegistry-3.0")

beqlfu:SetFuBarOption('hasIcon', true)
beqlfu:SetFuBarOption('iconPath', "Interface\\Icons\\INV_Letter_03")
beqlfu:SetFuBarOption('title', "bEQL")
beqlfu:SetFuBarOption('name', "beql")
beqlfu:SetFuBarOption('revision', beql.revision)
beqlfu:SetFuBarOption('cannotDetachTooltip', true)
beqlfu:SetFuBarOption('overrideMenu', true)
beqlfu:SetFuBarOption('independentProfile', true)
beqlfu:SetFuBarOption('hideWithoutStandby', true)

-- this db is only a dummy, real data will saved in beql.db.profile.fubar
-- this dummy is needed to access text and icon functions
beqlfu:SetDatabase("beqlFuDB")

local function round(input, places)
	if not places then
			places = 0
	end
	if type(input) == "number" and type(places) == "number" then
			local pow = 1
			for i = 1, ceil(places) do
					pow = pow * 10
			end
			return floor(input * pow + 0.5) / pow
	end
end

-- create a frame to handle QUEST_LOG_UPDATE event
local f

function beqlfu:OnInitialize()
    local _,questEntries = GetNumQuestLogEntries()
--	beqlfu.db = LibStub("AceDB-3.0"):New("fubar")
--	beql.db:RegisterNamespace("fubar")
	beqlfu:SetFuBarText(questEntries.."/25")
	
	-- mak a update script
	f = CreateFrame("Frame")
	f:RegisterEvent("QUEST_LOG_UPDATE")
	f:SetScript("OnEvent", function(self, event) 
		if event == 'QUEST_LOG_UPDATE' then
			beqlfu:SetFuBarText(select(2,GetNumQuestLogEntries()).."/25")
		end
	end)
	
	if FuBar then
		hooksecurefunc(FuBar,"Plugin_StopDrag", function(self, plugin)
			-- get the panel id for Pluginpanel
			if not plugin or plugin:GetName() ~= 'beqlFu' then
				-- no valid plugin
				return
			end
			
			if beql.db then
				-- DB is loaded
				beql.db.profile.fubar.PanelID = plugin:GetPanel().id
			end
		end)
	end
end

local firstDone

function beqlfu:OnEnable()
	if not firstDone and beql.db then
		local fubaroptions = beql.db.profile.fubar
		beqlfu:SetFuBarOption("defaultPosition", fubaroptions.FubarPosition)
		beqlfu:SetFuBarOption("defaultMinimapPosition", fubaroptions.MinimapPosition)
		firstDone = true
	end
	
	-- correct panel position if needed
	if beql.db.profile.fubar.FubarPosition ~= 'MINIMAP' and FuBar then
		FuBar:ShowPlugin(beqlfu, beql.db.profile.fubar.PanelID or 1)
	end
	
	-- manage position on the panel
	if (not beqlfu:IsFuBarMinimapAttached()) and FuBar then
		print("manage plugin position")
		local panel = FuBar:GetPanel(beql.db.profile.fubar.PanelID)
		if panel and panel:HasPlugin(beqlfu) then
			panel:SetPluginSide(beqlfu, beql.db.profile.fubar.FubarPosition)
		end
	end
	
	-- manage text
	if (beql.db.profile.fubar.ShowText == true and not beqlfu:IsFuBarTextShown()) 
		or (beql.db.profile.fubar.ShowText == false and beqlfu:IsFuBarTextShown())
			then
				beqlfu:ToggleFuBarTextShown()
	end
	-- manage colored text
	if (beql.db.profile.fubar.ShowColoredText == true and not beqlfu:IsFuBarTextColored()) 
		or (beql.db.profile.fubar.ShowColoredText == false and beqlfu:IsFuBarTextColored())
			then
				beqlfu:ToggleFuBarTextColored()
	end
	-- manage Icon
	if (beql.db.profile.fubar.ShowIcon == true and not beqlfu:IsFuBarIconShown()) 
		or (beql.db.profile.fubar.ShowIcon == false and beqlfu:IsFuBarIconShown())
			then
				beqlfu:ToggleFuBarIconShown()
	end
	
	beql:debugprint("enable beqlfu")
end

local beqlfu_hook_OnDragStop_minimap

function beqlfu:UpdateFuBarPlugin()

	if not beqlfu_hook_OnDragStop_minimap then
		-- add function to minimap icon dragging, to get the icon position
		local MinimapButton = _G[beqlfu:GetFrame():GetName() ..  "MinimapButton"]
		if MinimapButton and type(MinimapButton:GetScript("OnDragStop")) == 'function' then
			MinimapButton:HookScript("OnDragStop", function()
				beql.db.profile.fubar.MinimapPosition = round(beqlfu.db.profile.minimapPosition)
			end)
			beqlfu_hook_OnDragStop_minimap = true
		end
	end
	
end

function beqlfu:UpdateFuBarTooltip()
	if not beql.db.profile.fubar.ShowTooltip then
		return
	end
	
	if beqlfu:IsFuBarMinimapAttached() then
		GameTooltip:SetOwner(_G[beqlfu:GetFrame():GetName() .. "MinimapButton"],"ANCHOR_BOTTOMLEFT",30,0)
	else
		GameTooltip:SetOwner(beqlfu:GetFrame(),"ANCHOR_BOTTOM",0,0)
	end
	
	local questEntries = select(2, GetNumQuestLogEntries())
	local numfinished = select(2, beqlQ:GetNumQuests())
	beqlfu:SetFuBarText(questEntries.."/25")
	
	-- build Gametooltip
	
	-- title
	GameTooltip:AddLine(beqlfu:GetName())
	GameTooltip:AddLine(" ") -- spacer
	
	-- num quests
	GameTooltip:AddDoubleLine(L["|cffffffffQuests|r"],questEntries)
	
	-- num watched quests
	GameTooltip:AddDoubleLine(L["|cffff8000Tracked Quests|r"],GetNumQuestWatches())
	
	-- num completed quests
	GameTooltip:AddDoubleLine(L["|cff00d000Completed Quests|r"], numfinished)
	GameTooltip:AddLine(" ") -- spacer
	
	-- tooltip hint
	GameTooltip:AddLine(L["|cffeda55fClick|r to open Quest Log and |cffeda55fShift+Click|r to open Waterfall config"] .. L[". |cffeda55fRightclick|r to open FuBar config."],0,1,0,true)
	
	GameTooltip:Show()
end

function beqlfu:OpenMenu()
	-- show fubar config instead of a menu
	beql:OpenBlizzardOption("fubar")
end

function beqlfu:OnFuBarClick()
	if IsShiftKeyDown() then
		beql:OpenBlizzardOption("main")
	else
		ToggleFrame(QuestLogFrame);
	end
end

-- EOF --